@@ -1,6 +1,6 @@
-( cd usr/doc/dbus-glib-0.98 ; rm -rf html )
-( cd usr/doc/dbus-glib-0.98 ; ln -sf ../../share/gtk-doc/html/dbus-glib/ html )
-( cd usr/lib ; rm -rf libdbus-glib-1.so.2 )
-( cd usr/lib ; ln -sf libdbus-glib-1.so.2.2.2 libdbus-glib-1.so.2 )
 ( cd usr/lib ; rm -rf libdbus-glib-1.so )
 ( cd usr/lib ; ln -sf libdbus-glib-1.so.2.2.2 libdbus-glib-1.so )
+( cd usr/lib ; rm -rf libdbus-glib-1.so.2 )
+( cd usr/lib ; ln -sf libdbus-glib-1.so.2.2.2 libdbus-glib-1.so.2 )
+( cd usr/doc/dbus-glib-0.100.2 ; rm -rf html )
+( cd usr/doc/dbus-glib-0.100.2 ; ln -sf ../../share/gtk-doc/html/dbus-glib/ html )
